/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the HP 300, 400, and 700 series
 * keyboards.  By Dave Brooks <dbrooks@inel.gov>
 */

static const KeyCode hpitf_codes [] = {

  /* Row 0 */
  15, 86,
  84, 83, 82, 81, 80, 88, 89, 90, 91, 92,
  94, 95,
  45, 41, 43, 47,

  /* Row 2 */
  71, 70, 69, 68, 67, 66, 65, 64, 96, 97, 98, 99, 100, 101,
  102, 103,
  29, 25, 27, 31,

  /* Row 3 */
  63, 62, 61, 60, 59, 58, 57, 56, 104, 105, 106, 107, 108, 109,
  110, 111,
  21, 17, 19, 23,

  /* Row 4 */
  55, 14, 53, 52, 51, 50, 49, 48, 112, 113, 114, 115, 116, 117,
  118, 119,
  16, 18, 20, 22,

  /* Row 5 */
  39, 13, 36, 35, 34, 33, 32, 128, 120, 121, 122, 123, 12,
  125, 134, 127,
  24, 26, 28, 46,

  /* Row 6 */
  87,
  11, 129, 10,
  132, 133, 135,
  30, 44
};
